function getUniqueValues(count, min, max) {
    const values = [];
    while (values.length < count) {
        const randomValue = Math.floor(Math.random() * (max - values.length - min)) + min;
        values.push(values.slice().sort((a, b) => a - b).reduce((newValue, oldValue) => ((newValue >= oldValue) ? (newValue + 1) : newValue), randomValue));
    }
    return values;
}

function generateQuestion(winkel) {
    const frage = {
        "html": "Für welche andere Winkel aus <code>[0°; 360°[</code> hat " + ((Math.random() < 0.5) ? 'Sinus' : 'Kosinus') + " denselben Betrag wie <code>" + winkel + "°</code>?",
        "keepOrder": true,
        "singlechoice": false,
        "choices": [
            { "html": "Kleinster anderer Winkel: ", "unit": "°", "type": "number", size: 3, min: 0, max: 359, step: 1 },
            { "html": "Ggf. zweitkleinster anderer Winkel: ", "unit": "°", "type": "number", size: 3, min: 0, max: 359, step: 1 },
            { "html": "Ggf. drittkleinster anderer Winkel: ", "unit": "°", "type": "number", size: 3, min: 0, max: 359, step: 1 },
            { "html": "Ggf. viertkleinster anderer Winkel: ", "unit": "°", "type": "number", size: 3, min: 0, max: 359, step: 1 },
            { "html": "Ggf. fünftkleinster anderer Winkel: ", "unit": "°", "type": "number", size: 3, min: 0, max: 359, step: 1 }
        ]
    }
    frage.response = 'In Frage kommen (wie immer) die Winkel ';
    frage.response += '<code>180° - ' + winkel + '° = ' + (180 - winkel) + '°</code>';
    if (winkel > 180)
        frage.response += ' (entspricht <code>360° - ' + (winkel - 180) + '° = ' + (540 - winkel) + '°</code>)';
    frage.response += ', <code>180° + ' + winkel + '° = ' + (180 + winkel) + '°</code>';
    if (winkel > 180)
        frage.response += ' (entspricht <code>' + (winkel + 180) + '° - 360° = ' + (winkel - 180) + '°</code>)';
    frage.response += ' und <code>360° - ' + winkel + '° = ' + (360 - winkel) + '°</code>.';
    const andere = [360 - winkel, (540 - winkel) % 360, (540 + winkel) % 360].filter((anderer, index, arr) => (anderer != winkel && arr.indexOf(anderer) == index));
    andere.sort((a, b) => a - b);
    andere.forEach((winkel, index) => {
        const choice = frage.choices[index];
        choice.accept = winkel;
        choice.correct = true;
    });
    if (andere.length < 3)
        frage.response += ' Davon müssen doppelte Winkel bzw. der ursprüngliche Winkel ' + winkel + '° aussortiert werden.';
    else
        frage.response += ' Sortiert sind diese drei Winkel die gesuchte Lösung.';
    return frage;
}

window.MultipleChoiceTestData = {
    // Optional: Wie viele Versuche hat der/die Lernende (Standardwert: Unendlich)
    "maxTries": Infinity,

    // Optional: Soll statt der Anzahl an nötigen Versuchen bewertet werden, wie gut der/die Lernende abschneidet?
    "reportScore": false,

    // Optional: Sollen die Fragen nicht durchgemischt werden?
    "keepOrder": false,

    // Optional: Wie soll bewertet werden?
    // "questions"  → Standardwert, Frage kann entweder richtig sein (1 von 1 Punkt) oder falsch (0 von 1 Punkt)
    // "average"    → Durchschnittlicher Prozentsatz an richtig ausgewählten bzw. richtig nicht ausgewählten Antwortmöglichkeiten pro auswählbaren Antwortmöglichkeiten bei jeder Frage
    // "choices"    → Anteil der richtig ausgewählten Antwortmöglichkeiten pro auswählbaren Antwortmöglichkeiten
    "countMode": "questions",

    // Wie viele Fragen sollen für einen Test gezogen werden?
    "questionsPerTest": 5,

    // Welcher Anteil muss mindestens richtig sein, um zu bestehen?
    "threshold": 1,

    // Optional: Begrüßungstext
    "htmlIntro": "<p>Trage alle gesuchten Winkel aus <code>[0°; 360°[</code> sortiert nach Größe ein. Und keinen doppelt, ggf. bleibt ein Feld frei:</p>",

    // Verfügbare Fragen
    "questions": [
    ],

    // Fragengeneratoren
    "generators": [
        arrFragen => getUniqueValues(5, 0, 35).forEach(winkel => arrFragen.push(generateQuestion(winkel * 10)))
    ]
}
